@@ -237,6 +237,7 @@ spi_dec_x11_get_keycode (SpiDEController *controller,
 			 * Long-term fix is to extend the X keymap here instead of replace entries.
 			 */
 			priv->reserved_reset_timeout = g_timeout_add (500, spi_dec_reset_reserved, priv);
+			g_source_set_name_by_id (priv->reserved_reset_timeout, "[at-spi2-core] spi_dec_reset_reserved");
 		}		
 		if (modmask)
 			*modmask = 0;
@@ -1164,8 +1165,6 @@ spi_dec_x11_synth_keystring (SpiDEController *controller, guint synth_type, gint
 	const gchar *c;
 	KeySym keysym;
 
-	maxlen = strlen (keystring) + 1;
-	keysyms = g_new0 (KeySym, maxlen);
 	if (!(keystring && *keystring && g_utf8_validate (keystring, -1, &c))) { 
 		retval = FALSE;
 	} 
@@ -1173,6 +1172,9 @@ spi_dec_x11_synth_keystring (SpiDEController *controller, guint synth_type, gint
 #ifdef SPI_DEBUG
 		fprintf (stderr, "[keystring synthesis attempted on %s]\n", keystring);
 #endif
+		maxlen = strlen (keystring) + 1;
+		keysyms = g_new0 (KeySym, maxlen);
+
 		while (keystring && (unichar = g_utf8_get_char (keystring))) {
 			char bytes[6];
 			gint mbytes;
@@ -1206,8 +1208,9 @@ spi_dec_x11_synth_keystring (SpiDEController *controller, guint synth_type, gint
 			}
 		}
 		XSynchronize (spi_get_display (), FALSE);
+
+		g_free (keysyms);
 	}
-	g_free (keysyms);
 
 	if (synth_type == Accessibility_KEY_SYM) {
 		keysym = keycode;
@@ -1373,6 +1376,7 @@ wait_for_release_event (XEvent          *event,
 {
   pressed_event = spi_keystroke_from_x_key_event ((XKeyEvent *) event);
   check_release_handler = g_timeout_add (CHECK_RELEASE_DELAY, check_release, &pressed_event);
+  g_source_set_name_by_id (check_release_handler, "[at-spi2-core] check_release");
 }
 
 static void
